==> create-fly-1.21.8-6.0.8-1-sources.jar: com/zurrtum/create/content/logistics/depot/EjectorBlock.java <==
package com.zurrtum.create.content.logistics.depot;

import com.zurrtum.create.*;
import com.zurrtum.create.catnip.math.VecHelper;
import com.zurrtum.create.content.kinetics.base.HorizontalKineticBlock;
import com.zurrtum.create.content.logistics.depot.EjectorBlockEntity.State;
import com.zurrtum.create.foundation.block.IBE;
import com.zurrtum.create.foundation.block.ProperWaterloggedBlock;
import com.zurrtum.create.foundation.block.SlipperinessControlBlock;
import com.zurrtum.create.foundation.item.ItemHelper;
import com.zurrtum.create.infrastructure.items.ItemInventoryProvider;
import com.zurrtum.create.infrastructure.packet.c2s.EjectorTriggerPacket;
import org.jetbrains.annotations.Nullable;

import java.util.Optional;
import net.minecraft.class_10;
import net.minecraft.class_10225;
import net.minecraft.class_1263;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2350.class_2351;
import net.minecraft.class_243;
import net.minecraft.class_2591;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689.class_2690;
import net.minecraft.class_3610;
import net.minecraft.class_3726;
import net.minecraft.class_3965;
import net.minecraft.class_4538;
import net.minecraft.class_5819;
import net.minecraft.class_9904;

public class EjectorBlock extends HorizontalKineticBlock implements IBE<EjectorBlockEntity>, ProperWaterloggedBlock, SlipperinessControlBlock, ItemInventoryProvider<EjectorBlockEntity> {

    public EjectorBlock(class_2251 properties) {
        super(properties);
        method_9590(method_9564().method_11657(WATERLOGGED, false));
    }

    @Override
    protected void method_9515(class_2690<class_2248, class_2680> pBuilder) {
        super.method_9515(pBuilder.method_11667(WATERLOGGED));
    }

    @Override
    public class_1263 getInventory(class_1936 world, class_2338 pos, class_2680 state, EjectorBlockEntity blockEntity, class_2350 context) {
        return blockEntity.depotBehaviour.itemHandler;
    }

    @Override
    public class_3610 method_9545(class_2680 pState) {
        return fluidState(pState);
    }

    @Override
    public class_2680 method_9559(
        class_2680 pState,
        class_4538 pLevel,
        class_10225 tickView,
        class_2338 pCurrentPos,
        class_2350 pDirection,
        class_2338 pNeighborPos,
        class_2680 pNeighborState,
        class_5819 random
    ) {
        updateWater(pLevel, tickView, pState, pCurrentPos);
        return pState;
    }

    @Override
    public class_2680 method_9605(class_1750 pContext) {
        return withWater(super.method_9605(pContext), pContext);
    }

    @Override
    public class_265 method_9530(class_2680 p_220053_1_, class_1922 p_220053_2_, class_2338 p_220053_3_, class_3726 p_220053_4_) {
        return AllShapes.CASING_13PX.get(class_2350.field_11036);
    }

    @Override
    public float getSlipperiness(class_4538 world, class_2338 pos) {
        return getBlockEntityOptional(world, pos).filter(ete -> ete.state == State.LAUNCHING).isPresent() ? 1f : super.method_9499();
    }

    @Override
    public void method_9612(
        class_2680 state,
        class_1937 world,
        class_2338 pos,
        class_2248 p_220069_4_,
        @Nullable class_9904 wireOrientation,
        boolean p_220069_6_
    ) {
        withBlockEntityDo(world, pos, EjectorBlockEntity::updateSignal);
    }

    @Override
    public void method_9554(class_1937 p_180658_1_, class_2680 p_152427_, class_2338 p_180658_2_, class_1297 p_180658_3_, double p_180658_4_) {
        Optional<EjectorBlockEntity> blockEntityOptional = getBlockEntityOptional(p_180658_1_, p_180658_2_);
        if (blockEntityOptional.isPresent() && !p_180658_3_.method_21750()) {
            p_180658_3_.method_5747(p_180658_4_, 1.0F, p_180658_1_.method_48963().method_48827());
            return;
        }
        super.method_9554(p_180658_1_, p_152427_, p_180658_2_, p_180658_3_, p_180658_4_);
    }

    @Override
    public void method_9502(class_1922 worldIn, class_1297 entityIn) {
        super.method_9502(worldIn, entityIn);
        class_2338 position = entityIn.method_24515();
        if (!worldIn.method_8320(position).method_27852(AllBlocks.WEIGHTED_EJECTOR))
            return;
        if (!entityIn.method_5805())
            return;
        if (entityIn.method_21750())
            return;
        if (!ItemHelper.fromItemEntity(entityIn).method_7960()) {
            SharedDepotBlockMethods.onLanded(worldIn, entityIn);
            return;
        }

        Optional<EjectorBlockEntity> teProvider = getBlockEntityOptional(worldIn, position);
        if (!teProvider.isPresent())
            return;

        EjectorBlockEntity ejectorBlockEntity = teProvider.get();
        if (ejectorBlockEntity.getState() == State.RETRACTING)
            return;
        if (ejectorBlockEntity.powered)
            return;
        if (ejectorBlockEntity.launcher.getHorizontalDistance() == 0)
            return;

        if (entityIn.method_24828()) {
            entityIn.method_24830(false);
            class_243 center = VecHelper.getCenterOf(position).method_1031(0, 7 / 16f, 0);
            class_243 positionVec = entityIn.method_19538();
            double diff = center.method_1022(positionVec);
            entityIn.method_18800(0, -0.125, 0);
            class_243 vec = center.method_1019(positionVec).method_1021(.5f);
            if (diff > 4 / 16f) {
                entityIn.method_5814(vec.field_1352, vec.field_1351, vec.field_1350);
                return;
            }
        }

        ejectorBlockEntity.activate();
        ejectorBlockEntity.notifyUpdate();
        if (entityIn.method_37908().field_9236)
            AllClientHandle.INSTANCE.sendPacket(new EjectorTriggerPacket(ejectorBlockEntity.method_11016()));
    }

    @Override
    protected class_1269 method_55765(
        class_1799 stack,
        class_2680 state,
        class_1937 level,
        class_2338 pos,
        class_1657 player,
        class_1268 hand,
        class_3965 hitResult
    ) {
        if (stack.method_31574(AllItems.WRENCH))
            return class_1269.field_52423;
        return SharedDepotBlockMethods.onUse(stack, state, level, pos, player, hand, hitResult);
    }

    @Override
    public class_2351 getRotationAxis(class_2680 state) {
        return state.method_11654(HORIZONTAL_FACING).method_10170().method_10166();
    }

    @Override
    public boolean hasShaftTowards(class_4538 world, class_2338 pos, class_2680 state, class_2350 face) {
        return getRotationAxis(state) == face.method_10166();
    }

    @Override
    public Class<EjectorBlockEntity> getBlockEntityClass() {
        return EjectorBlockEntity.class;
    }

    @Override
    public class_2591<? extends EjectorBlockEntity> getBlockEntityType() {
        return AllBlockEntityTypes.WEIGHTED_EJECTOR;
    }

    @Override
    public boolean method_9498(class_2680 state) {
        return true;
    }

    @Override
    public int method_9572(class_2680 blockState, class_1937 worldIn, class_2338 pos) {
        return SharedDepotBlockMethods.getComparatorInputOverride(blockState, worldIn, pos);
    }

    @Override
    protected boolean method_9516(class_2680 state, class_10 pathComputationType) {
        return false;
    }
}

==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/content/logistics/depot/EjectorBlock.java <==
package com.zurrtum.create.content.logistics.depot;

import com.zurrtum.create.*;
import com.zurrtum.create.catnip.math.VecHelper;
import com.zurrtum.create.content.kinetics.base.HorizontalKineticBlock;
import com.zurrtum.create.content.logistics.depot.EjectorBlockEntity.State;
import com.zurrtum.create.foundation.block.IBE;
import com.zurrtum.create.foundation.block.ProperWaterloggedBlock;
import com.zurrtum.create.foundation.block.SlipperinessControlBlock;
import com.zurrtum.create.foundation.item.ItemHelper;
import com.zurrtum.create.infrastructure.items.ItemInventoryProvider;
import com.zurrtum.create.infrastructure.packet.c2s.EjectorTriggerPacket;
import org.jetbrains.annotations.Nullable;

import java.util.Optional;
import net.minecraft.class_10;
import net.minecraft.class_10225;
import net.minecraft.class_1263;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2350.class_2351;
import net.minecraft.class_243;
import net.minecraft.class_2591;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689.class_2690;
import net.minecraft.class_3610;
import net.minecraft.class_3726;
import net.minecraft.class_3965;
import net.minecraft.class_4538;
import net.minecraft.class_5819;
import net.minecraft.class_9904;

public class EjectorBlock extends HorizontalKineticBlock implements IBE<EjectorBlockEntity>, ProperWaterloggedBlock, SlipperinessControlBlock, ItemInventoryProvider<EjectorBlockEntity> {

    public EjectorBlock(class_2251 properties) {
        super(properties);
        method_9590(method_9564().method_11657(WATERLOGGED, false));
    }

    @Override
    protected void method_9515(class_2690<class_2248, class_2680> pBuilder) {
        super.method_9515(pBuilder.method_11667(WATERLOGGED));
    }

    @Override
    public class_1263 getInventory(class_1936 world, class_2338 pos, class_2680 state, EjectorBlockEntity blockEntity, class_2350 context) {
        return blockEntity.depotBehaviour.itemHandler;
    }

    @Override
    public class_3610 method_9545(class_2680 pState) {
        return fluidState(pState);
    }

    @Override
    public class_2680 method_9559(
        class_2680 pState,
        class_4538 pLevel,
        class_10225 tickView,
        class_2338 pCurrentPos,
        class_2350 pDirection,
        class_2338 pNeighborPos,
        class_2680 pNeighborState,
        class_5819 random
    ) {
        updateWater(pLevel, tickView, pState, pCurrentPos);
        return pState;
    }

    @Override
    public class_2680 method_9605(class_1750 pContext) {
        return withWater(super.method_9605(pContext), pContext);
    }

    @Override
    public class_265 method_9530(class_2680 p_220053_1_, class_1922 p_220053_2_, class_2338 p_220053_3_, class_3726 p_220053_4_) {
        return AllShapes.CASING_13PX.get(class_2350.field_11036);
    }

    @Override
    public float getSlipperiness(class_4538 world, class_2338 pos) {
        return getBlockEntityOptional(world, pos).filter(ete -> ete.state == State.LAUNCHING).isPresent() ? 1f : super.method_9499();
    }

    @Override
    public void method_9612(
        class_2680 state,
        class_1937 world,
        class_2338 pos,
        class_2248 p_220069_4_,
        @Nullable class_9904 wireOrientation,
        boolean p_220069_6_
    ) {
        withBlockEntityDo(world, pos, EjectorBlockEntity::updateSignal);
    }

    @Override
    public void method_9554(class_1937 p_180658_1_, class_2680 p_152427_, class_2338 p_180658_2_, class_1297 p_180658_3_, double p_180658_4_) {
        Optional<EjectorBlockEntity> blockEntityOptional = getBlockEntityOptional(p_180658_1_, p_180658_2_);
        if (blockEntityOptional.isPresent() && !p_180658_3_.method_21750()) {
            p_180658_3_.method_5747(p_180658_4_, 1.0F, p_180658_1_.method_48963().method_48827());
            return;
        }
        super.method_9554(p_180658_1_, p_152427_, p_180658_2_, p_180658_3_, p_180658_4_);
    }

    @Override
    public void method_9502(class_1922 worldIn, class_1297 entityIn) {
        super.method_9502(worldIn, entityIn);
        class_2338 position = entityIn.method_24515();
        if (!worldIn.method_8320(position).method_27852(AllBlocks.WEIGHTED_EJECTOR))
            return;
        if (!entityIn.method_5805())
            return;
        if (entityIn.method_21750())
            return;
        if (!ItemHelper.fromItemEntity(entityIn).method_7960()) {
            SharedDepotBlockMethods.onLanded(worldIn, entityIn);
            return;
        }

        Optional<EjectorBlockEntity> teProvider = getBlockEntityOptional(worldIn, position);
        if (!teProvider.isPresent())
            return;

        EjectorBlockEntity ejectorBlockEntity = teProvider.get();
        if (ejectorBlockEntity.getState() == State.RETRACTING)
            return;
        if (ejectorBlockEntity.powered)
            return;
        if (ejectorBlockEntity.launcher.getHorizontalDistance() == 0)
            return;

        if (entityIn.method_24828()) {
            entityIn.method_24830(false);
            class_243 center = VecHelper.getCenterOf(position).method_1031(0, 7 / 16f, 0);
            class_243 positionVec = entityIn.method_73189();
            double diff = center.method_1022(positionVec);
            entityIn.method_18800(0, -0.125, 0);
            class_243 vec = center.method_1019(positionVec).method_1021(.5f);
            if (diff > 4 / 16f) {
                entityIn.method_5814(vec.field_1352, vec.field_1351, vec.field_1350);
                return;
            }
        }

        ejectorBlockEntity.activate();
        ejectorBlockEntity.notifyUpdate();
        if (entityIn.method_73183().method_8608())
            AllClientHandle.INSTANCE.sendPacket(new EjectorTriggerPacket(ejectorBlockEntity.method_11016()));
    }

    @Override
    protected class_1269 method_55765(
        class_1799 stack,
        class_2680 state,
        class_1937 level,
        class_2338 pos,
        class_1657 player,
        class_1268 hand,
        class_3965 hitResult
    ) {
        if (stack.method_31574(AllItems.WRENCH))
            return class_1269.field_52423;
        return SharedDepotBlockMethods.onUse(stack, state, level, pos, player, hand, hitResult);
    }

    @Override
    public class_2351 getRotationAxis(class_2680 state) {
        return state.method_11654(HORIZONTAL_FACING).method_10170().method_10166();
    }

    @Override
    public boolean hasShaftTowards(class_4538 world, class_2338 pos, class_2680 state, class_2350 face) {
        return getRotationAxis(state) == face.method_10166();
    }

    @Override
    public Class<EjectorBlockEntity> getBlockEntityClass() {
        return EjectorBlockEntity.class;
    }

    @Override
    public class_2591<? extends EjectorBlockEntity> getBlockEntityType() {
        return AllBlockEntityTypes.WEIGHTED_EJECTOR;
    }

    @Override
    public boolean method_9498(class_2680 state) {
        return true;
    }

    @Override
    public int method_9572(class_2680 blockState, class_1937 worldIn, class_2338 pos, class_2350 direction) {
        return SharedDepotBlockMethods.getComparatorInputOverride(blockState, worldIn, pos);
    }

    @Override
    protected boolean method_9516(class_2680 state, class_10 pathComputationType) {
        return false;
    }
}
